Input
=====

.. currentmodule:: nexoclom

.. autoclass:: Input
   :show-inheritance:

   .. rubric:: Methods Summary

   .. autosummary::

      ~Input.search
      ~Input.produce_image
      ~Input.run

   .. rubric:: Methods Documentation

   .. automethod:: search
   .. automethod:: produce_image
   .. automethod:: run
